@@ -946,13 +946,11 @@ bool View::showInfo(const vector<string> &text, int type)
 		ty += font.getLineHeight();
 	}
 
-	SDL_RenderPresent(mrc);
-
 	grabInput(0);
 	if (type == WT_YESNO)
 		ret = waitForConfirmation();
 	else
-		ret = waitForKey(WT_ANYKEY);
+		ret = waitForKey(type);
 	grabInput(1);
 	return ret;
 }
@@ -1631,40 +1629,41 @@ void View::showFinalHiscores()
 	x = (mw->getWidth() - w)/2;
 	y = h/2;
 	renderHiscore(theme.fNormal, theme.fNormal, x,y,w,h,true);
-	SDL_RenderPresent(mrc);
+
 	waitForKey(WT_ANYKEY);
 }
 
+/* Wait for any or pause key.
+ * The render target must not have been presented yet otherwise we get
+ * the wrong buffer content for createFromScreen(). */
 int View::waitForKey(int type)
 {
 	SDL_Event ev;
 	bool ret = true;
 	bool leave = false;
+	Image sshot;
+
+	sshot.createFromScreen();
+	SDL_RenderPresent(mrc);
 
 	SDL_PumpEvents();
 	SDL_FlushEvents(SDL_FIRSTEVENT,SDL_LASTEVENT);
 	while (!leave) {
 		/* handle events */
-		if (SDL_WaitEvent(&ev)) {
+		if (SDL_PollEvent(&ev)) {
 			if (ev.type == SDL_QUIT)
 				quitReceived = leave = true;
-			if (type == WT_ANYKEY && (ev.type == SDL_KEYUP ||
-						ev.type == SDL_MOUSEBUTTONUP))
-				leave = true;
 			else if (ev.type == SDL_KEYUP) {
-				int sc = ev.key.keysym.scancode;
-				if (type == WT_YESNO) {
-					if (sc == SDL_SCANCODE_Y || sc == SDL_SCANCODE_Z)
-						ret = leave = true;
-					if (sc == SDL_SCANCODE_N || sc == SDL_SCANCODE_ESCAPE) {
-						ret = false;
-						leave = true;
-					}
-				} else if (type == WT_PAUSE)
-					if (sc == SDL_SCANCODE_P)
-						ret = leave = true;
-			}
+				if (type == WT_ANYKEY || (type == WT_PAUSE &&
+						ev.key.keysym.scancode == SDL_SCANCODE_P))
+					leave = true;
+			} else if (ev.type == SDL_MOUSEBUTTONUP && type == WT_ANYKEY)
+				leave = true;
 		}
+
+		SDL_Delay(20);
+		sshot.copy();
+		SDL_RenderPresent(mrc);
 		SDL_FlushEvent(SDL_MOUSEMOTION);
 	}
 	SDL_FlushEvents(SDL_FIRSTEVENT,SDL_LASTEVENT);
@@ -1848,8 +1847,6 @@ void View::showHelp()
 	renderExtraHelp(theme.bricks, 18, 0, _("Explosive Brick"), x, y);
 	renderExtraHelp(theme.bricks, 19, 0, _("Growing Brick"), x2, y);
 
-	SDL_RenderPresent(mrc);
-
 	waitForInputRelease();
 	waitForKey(WT_ANYKEY);
 }
